@@ -21,6 +21,7 @@ SORT_OPTIONS = SortedDict((
     ('accel_15', _('Trending: %(minutes)d minutes' % {'minutes': 15})),
     ('accel_60', _('Trending: %(minutes)d minutes' % {'minutes': 60})),
 ))
+
 SORT_CLAUSES = {
     'priority': 'sentry_groupedmessage.score',
     'date': 'EXTRACT(EPOCH FROM sentry_groupedmessage.last_seen)',
@@ -29,16 +30,26 @@ SORT_CLAUSES = {
     'tottime': 'sentry_groupedmessage.time_spent_total',
     'avgtime': '(sentry_groupedmessage.time_spent_total / sentry_groupedmessage.time_spent_count)',
 }
+SCORE_CLAUSES = SORT_CLAUSES.copy()
+
 SQLITE_SORT_CLAUSES = SORT_CLAUSES.copy()
 SQLITE_SORT_CLAUSES.update({
     'date': 'sentry_groupedmessage.last_seen',
     'new': 'sentry_groupedmessage.first_seen',
 })
+SQLITE_SCORE_CLAUSES = SQLITE_SORT_CLAUSES.copy()
+
 MYSQL_SORT_CLAUSES = SORT_CLAUSES.copy()
 MYSQL_SORT_CLAUSES.update({
+    'date': 'sentry_groupedmessage.last_seen',
+    'new': 'sentry_groupedmessage.first_seen',
+})
+MYSQL_SCORE_CLAUSES = SCORE_CLAUSES.copy()
+MYSQL_SCORE_CLAUSES.update({
     'date': 'UNIX_TIMESTAMP(sentry_groupedmessage.last_seen)',
     'new': 'UNIX_TIMESTAMP(sentry_groupedmessage.first_seen)',
 })
+
 SEARCH_SORT_OPTIONS = SortedDict((
     ('score', _('Score')),
     ('date', _('Last Seen')),
